Search Opinions
Author: Opinions/Memorandum Decisions
Description: AZ Supreme Court
Keywords: ,DotNetNuke,DNN

# Arizona Judicial Branch

Skip to main navigation | Skip to main content | Skip to footer navigation

## Opinions/Memorandum Decisions

Search Opinions/Memo Decs

Search filter ON - 498 records found Clear search filter Court: Arizona Supreme Court | Search Decisions

1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | ...
|  | 2/20/2014 |  | CV-13-0005 | HON. FIELDS et al v ELECTED OFFICIALS RETIREMENT | OPINION
| Robert M Brutinel, Author; Rebecca White Berch, Concur; Scott Bales, Concur; John Pelander, Concur; Ann A. Scott Timmer, Concur
| Constitutionality Decision Holding that SB 1609 (2011) violates Article 29, Section 1(C) of the Arizona Constitution by diminishing and impairing public retirement system benefits.
|  | 1/24/2014 |  | CV-13-0170 | BILL BEVERAGE et ux v PULLMAN & COMLEY/MORRIS | OPINION
| Rebecca White Berch, Author; Scott Bales, Concur; John Pelander, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
|  | 1/17/2014 |  | CR-11-0043 | STATE OF ARIZONA v SHAWNA FORDE | OPINION
| Ann A. Scott Timmer, Author; Rebecca White Berch, Concur; Scott Bales, Concur; John Pelander, Concur; Robert M Brutinel, Concur
|  | 1/13/2014 |  | SB-13-0026 | In the Matter of MICHAEL E ISLER | MEMORANDUM
| Ann A. Scott Timmer, Author; Rebecca White Berch, Concur; Scott Bales, Concur; John Pelander, Concur; Robert M Brutinel, Concur
|  | 12/27/2013 |  | CR-11-0331 | STATE OF ARIZONA v WILLIAM CRAIG MILLER | OPINION
| Rebecca White Berch, Author; Scott Bales, Concur; John Pelander, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
|  | 11/21/2013 |  | CR-09-0081 | STATE OF ARIZONA v CHRISTOPHER MATHEW PAYNE | OPINION
| Rebecca White Berch, Author; John Pelander, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur; Scott Bales, Concur in part; Dissent in part
| This Opinion Amends the Opinion filed on August 21, 2013.
|  | 11/21/2013 |  | CR-13-0060 | STATE OF ARIZONA v RICHARD J GLASSEL | OPINION
| Rebecca White Berch, Author; Scott Bales, Concur; John Pelander, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
|  | 11/7/2013 |  | CR-13-0087 | STATE OF ARIZONA v ANTHONY DURAN | OPINION
| John Pelander, Author; Rebecca White Berch, Concur; Scott Bales, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
|  | 10/23/2013 |  | CR-11-0157 | STATE OF ARIZONA v STEPHEN DOUGLAS REEVES | OPINION
| Scott Bales, Author; Rebecca White Berch, Concur; John Pelander, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
| Constitutionality Decision Holding A.R.S. §§ 13-752(G), (I) (presentation of evidence to penalty phase jury) and A.R.S. §§ 13-751(C), (F) (burden of establishing mitigating circumstances) constitutional under U.S. Const. amend. 8 (cruel and unusual punishment) and U.S. Const. amend. 14 (due process).
|  | 9/26/2013 |  | CV-13-0039 | CAVE CREEK UNIFIED SCHOOL et al v DUCEY/STATE | OPINION
| John Pelander, Author; Rebecca White Berch, Concur; Scott Bales, Concur; Robert M Brutinel, Concur; Ann A. Scott Timmer, Concur
| Constitutionality Decision Holding that HB 2008 (2010) violates the Voter Protection Act, Ariz. Const. art. 4, pt. 1, § 1(6)(B)-(C), (14), by effectively repealing, amending, or superseding certain public education funding requirements in A.R.S. § 15-901.01, a voter-approved referendum measure.
1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | ...

Search Decision Document Text